# Afori Utils

This package contains an aggregation of tools used by Dor Miron.
Afori is my cat, and he contributed some changes now and then.

## Installation

Run the following to install:

```python 
pip install afori_utils
```

## Usage
```python
from afori_utils import pyplot_utils
from afori_utils import sync_utils
from afori_utils import debug_utils
```

##### add usages (here what is the purpose)
here the actual code

